Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(151)

Unified Diff: chrome/browser/upgrade_detector_impl.cc

Issue 2710713004: Revert "Use the Windows MDM API to check if the machine is being managed." (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/upgrade_detector_impl.cc
diff --git a/chrome/browser/upgrade_detector_impl.cc b/chrome/browser/upgrade_detector_impl.cc
index 1d85b7dd30edb67c93a824d2f3d85532026a71e8..4b7756595ac8ddb5f88d9f5124a595e3c69efc29 100644
--- a/chrome/browser/upgrade_detector_impl.cc
+++ b/chrome/browser/upgrade_detector_impl.cc
@@ -409,8 +409,8 @@ bool UpgradeDetectorImpl::DetectOutdatedInstall() {
return false;
#if defined(OS_WIN)
- // Don't show the update bubbles to enterprise users.
- if (base::win::IsEnterpriseManaged())
+ // Don't show the update bubbles to enterprise users (i.e., on a domain).
+ if (base::win::IsEnrolledToDomain())
return false;
#endif
}
« no previous file with comments | « chrome/browser/safe_browsing/incident_reporting/environment_data_collection_win.cc ('k') | chrome/common/crash_keys.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698